# -*- coding: utf-8 -*-
from django.template import TemplateSyntaxError

from .utils import ResponseError


class RaiseResponse:
    """
    Processes exceptions, returning a response if it's the case or raising
    the exception.
    """
    def process_exception(self, request, exception):

        if isinstance(exception, ResponseError):
            return exception.response

        if isinstance(exception, TemplateSyntaxError):
            if getattr(exception, 'exc_info', 0):
                try:
                    exception = exception.exc_info[1]
                except:
                    raise exception



#!/usr/bin/env python
import io
import os
import sys

from setuptools import find_packages, setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    os.system('python setup.py bdist_wheel upload')
    sys.exit()


readme = io.open('README.rst', 'r', encoding='utf-8').read()

setup(
    name='django-raise-response',
    description='Raise any response object in Django',
    long_description=readme,
    url='https://github.com/wearewhys/django-raise-response',
    author='Jacopo Cascioli',
    author_email='jacopocascioli@gmail.com',
    license='MIT',
    version='0.1.0',
    packages=find_packages(),
    tests_require=[],
    setup_requires=[],
    install_requires=[],
    classifiers=[
        'Development Status :: 4 - Beta',
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Framework :: Django'
    ]
)
